pywaterinfo package
===================

Waterinfo
---------

.. automodule:: pywaterinfo
   :members:
   :undoc-members:
   :show-inheritance:

Utility functions
-----------------

.. automodule:: pywaterinfo.utils
   :members:
   :undoc-members:
   :show-inheritance:
